@@ -1,4 +1,4 @@
-/* $OpenBSD: dsaparam.c,v 1.11 2019/07/14 03:30:45 guenther Exp $ */
+/* $OpenBSD: dsaparam.c,v 1.16 2025/01/19 10:24:17 tb Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -80,7 +80,6 @@
 #include <openssl/x509.h>
 
 static struct {
-	int C;
 	int genkey;
 	char *infile;
 	int informat;
@@ -88,60 +87,54 @@ static struct {
 	char *outfile;
 	int outformat;
 	int text;
-} dsaparam_config;
+} cfg;
 
 static const struct option dsaparam_options[] = {
-	{
-		.name = "C",
-		.desc = "Convert DSA parameters into C code",
-		.type = OPTION_FLAG,
-		.opt.flag = &dsaparam_config.C,
-	},
 	{
 		.name = "genkey",
 		.desc = "Generate a DSA key",
 		.type = OPTION_FLAG,
-		.opt.flag = &dsaparam_config.genkey,
+		.opt.flag = &cfg.genkey,
 	},
 	{
 		.name = "in",
 		.argname = "file",
 		.desc = "Input file (default stdin)",
 		.type = OPTION_ARG,
-		.opt.arg = &dsaparam_config.infile,
+		.opt.arg = &cfg.infile,
 	},
 	{
 		.name = "inform",
 		.argname = "format",
 		.desc = "Input format (DER or PEM (default))",
 		.type = OPTION_ARG_FORMAT,
-		.opt.value = &dsaparam_config.informat,
+		.opt.value = &cfg.informat,
 	},
 	{
 		.name = "noout",
 		.desc = "No output",
 		.type = OPTION_FLAG,
-		.opt.flag = &dsaparam_config.noout,
+		.opt.flag = &cfg.noout,
 	},
 	{
 		.name = "out",
 		.argname = "file",
 		.desc = "Output file (default stdout)",
 		.type = OPTION_ARG,
-		.opt.arg = &dsaparam_config.outfile,
+		.opt.arg = &cfg.outfile,
 	},
 	{
 		.name = "outform",
 		.argname = "format",
 		.desc = "Output format (DER or PEM (default))",
 		.type = OPTION_ARG_FORMAT,
-		.opt.value = &dsaparam_config.outformat,
+		.opt.value = &cfg.outformat,
 	},
 	{
 		.name = "text",
 		.desc = "Print as text",
 		.type = OPTION_FLAG,
-		.opt.flag = &dsaparam_config.text,
+		.opt.flag = &cfg.text,
 	},
 	{ NULL },
 };
@@ -150,13 +143,13 @@ static void
 dsaparam_usage(void)
 {
 	fprintf(stderr,
-	    "usage: dsaparam [-C] [-genkey] [-in file]\n"
+	    "usage: dsaparam [-genkey] [-in file]\n"
 	    "    [-inform format] [-noout] [-out file] [-outform format]\n"
 	    "    [-text] [numbits]\n\n");
 	options_usage(dsaparam_options);
 }
 
-static int dsa_cb(int p, int n, BN_GENCB * cb);
+static int dsa_cb(int p, int n, BN_GENCB *cb);
 
 int
 dsaparam_main(int argc, char **argv)
@@ -164,21 +157,20 @@ dsaparam_main(int argc, char **argv)
 	DSA *dsa = NULL;
 	int i;
 	BIO *in = NULL, *out = NULL;
+	BN_GENCB *cb = NULL;
 	int ret = 1;
 	int numbits = -1;
 	char *strbits = NULL;
 
-	if (single_execution) {
-		if (pledge("stdio cpath wpath rpath", NULL) == -1) {
-			perror("pledge");
-			exit(1);
-		}
+	if (pledge("stdio cpath wpath rpath", NULL) == -1) {
+		perror("pledge");
+		exit(1);
 	}
 
-	memset(&dsaparam_config, 0, sizeof(dsaparam_config));
+	memset(&cfg, 0, sizeof(cfg));
 
-	dsaparam_config.informat = FORMAT_PEM;
-	dsaparam_config.outformat = FORMAT_PEM;
+	cfg.informat = FORMAT_PEM;
+	cfg.outformat = FORMAT_PEM;
 
 	if (options_parse(argc, argv, dsaparam_options, &strbits, NULL) != 0) {
 		dsaparam_usage();
@@ -200,26 +192,32 @@ dsaparam_main(int argc, char **argv)
 		ERR_print_errors(bio_err);
 		goto end;
 	}
-	if (dsaparam_config.infile == NULL)
+	if (cfg.infile == NULL)
 		BIO_set_fp(in, stdin, BIO_NOCLOSE);
 	else {
-		if (BIO_read_filename(in, dsaparam_config.infile) <= 0) {
-			perror(dsaparam_config.infile);
+		if (BIO_read_filename(in, cfg.infile) <= 0) {
+			perror(cfg.infile);
 			goto end;
 		}
 	}
-	if (dsaparam_config.outfile == NULL) {
+	if (cfg.outfile == NULL) {
 		BIO_set_fp(out, stdout, BIO_NOCLOSE);
 	} else {
-		if (BIO_write_filename(out, dsaparam_config.outfile) <= 0) {
-			perror(dsaparam_config.outfile);
+		if (BIO_write_filename(out, cfg.outfile) <= 0) {
+			perror(cfg.outfile);
 			goto end;
 		}
 	}
 
 	if (numbits > 0) {
-		BN_GENCB cb;
-		BN_GENCB_set(&cb, dsa_cb, bio_err);
+		if ((cb = BN_GENCB_new()) == NULL) {
+			BIO_printf(bio_err,
+			    "Error allocating BN_GENCB object\n");
+			goto end;
+		}
+
+		BN_GENCB_set(cb, dsa_cb, bio_err);
+
 		dsa = DSA_new();
 		if (!dsa) {
 			BIO_printf(bio_err, "Error allocating DSA object\n");
@@ -227,14 +225,14 @@ dsaparam_main(int argc, char **argv)
 		}
 		BIO_printf(bio_err, "Generating DSA parameters, %d bit long prime\n", numbits);
 		BIO_printf(bio_err, "This could take some time\n");
-		if (!DSA_generate_parameters_ex(dsa, numbits, NULL, 0, NULL, NULL, &cb)) {
+		if (!DSA_generate_parameters_ex(dsa, numbits, NULL, 0, NULL, NULL, cb)) {
 			ERR_print_errors(bio_err);
 			BIO_printf(bio_err, "Error, DSA key generation failed\n");
 			goto end;
 		}
-	} else if (dsaparam_config.informat == FORMAT_ASN1)
+	} else if (cfg.informat == FORMAT_ASN1)
 		dsa = d2i_DSAparams_bio(in, NULL);
-	else if (dsaparam_config.informat == FORMAT_PEM)
+	else if (cfg.informat == FORMAT_PEM)
 		dsa = PEM_read_bio_DSAparams(in, NULL, NULL, NULL);
 	else {
 		BIO_printf(bio_err, "bad input format specified\n");
@@ -245,65 +243,13 @@ dsaparam_main(int argc, char **argv)
 		ERR_print_errors(bio_err);
 		goto end;
 	}
-	if (dsaparam_config.text) {
+	if (cfg.text) {
 		DSAparams_print(out, dsa);
 	}
-	if (dsaparam_config.C) {
-		unsigned char *data;
-		int l, len, bits_p;
-
-		len = BN_num_bytes(dsa->p);
-		bits_p = BN_num_bits(dsa->p);
-		data = malloc(len + 20);
-		if (data == NULL) {
-			perror("malloc");
-			goto end;
-		}
-		l = BN_bn2bin(dsa->p, data);
-		printf("static unsigned char dsa%d_p[] = {", bits_p);
-		for (i = 0; i < l; i++) {
-			if ((i % 12) == 0)
-				printf("\n\t");
-			printf("0x%02X, ", data[i]);
-		}
-		printf("\n\t};\n");
-
-		l = BN_bn2bin(dsa->q, data);
-		printf("static unsigned char dsa%d_q[] = {", bits_p);
-		for (i = 0; i < l; i++) {
-			if ((i % 12) == 0)
-				printf("\n\t");
-			printf("0x%02X, ", data[i]);
-		}
-		printf("\n\t};\n");
-
-		l = BN_bn2bin(dsa->g, data);
-		printf("static unsigned char dsa%d_g[] = {", bits_p);
-		for (i = 0; i < l; i++) {
-			if ((i % 12) == 0)
-				printf("\n\t");
-			printf("0x%02X, ", data[i]);
-		}
-		free(data);
-		printf("\n\t};\n\n");
-
-		printf("DSA *get_dsa%d()\n\t{\n", bits_p);
-		printf("\tDSA *dsa;\n\n");
-		printf("\tif ((dsa = DSA_new()) == NULL) return(NULL);\n");
-		printf("\tdsa->p = BN_bin2bn(dsa%d_p, sizeof(dsa%d_p), NULL);\n",
-		    bits_p, bits_p);
-		printf("\tdsa->q = BN_bin2bn(dsa%d_q, sizeof(dsa%d_q), NULL);\n",
-		    bits_p, bits_p);
-		printf("\tdsa->g = BN_bin2bn(dsa%d_g, sizeof(dsa%d_g), NULL);\n",
-		    bits_p, bits_p);
-		printf("\tif ((dsa->p == NULL) || (dsa->q == NULL) || (dsa->g == NULL))\n");
-		printf("\t\t{ DSA_free(dsa); return(NULL); }\n");
-		printf("\treturn(dsa);\n\t}\n");
-	}
-	if (!dsaparam_config.noout) {
-		if (dsaparam_config.outformat == FORMAT_ASN1)
+	if (!cfg.noout) {
+		if (cfg.outformat == FORMAT_ASN1)
 			i = i2d_DSAparams_bio(out, dsa);
-		else if (dsaparam_config.outformat == FORMAT_PEM)
+		else if (cfg.outformat == FORMAT_PEM)
 			i = PEM_write_bio_DSAparams(out, dsa);
 		else {
 			BIO_printf(bio_err, "bad output format specified for outfile\n");
@@ -315,7 +261,7 @@ dsaparam_main(int argc, char **argv)
 			goto end;
 		}
 	}
-	if (dsaparam_config.genkey) {
+	if (cfg.genkey) {
 		DSA *dsakey;
 
 		if ((dsakey = DSAparams_dup(dsa)) == NULL)
@@ -325,9 +271,9 @@ dsaparam_main(int argc, char **argv)
 			DSA_free(dsakey);
 			goto end;
 		}
-		if (dsaparam_config.outformat == FORMAT_ASN1)
+		if (cfg.outformat == FORMAT_ASN1)
 			i = i2d_DSAPrivateKey_bio(out, dsakey);
-		else if (dsaparam_config.outformat == FORMAT_PEM)
+		else if (cfg.outformat == FORMAT_PEM)
 			i = PEM_write_bio_DSAPrivateKey(out, dsakey, NULL, NULL, 0, NULL, NULL);
 		else {
 			BIO_printf(bio_err, "bad output format specified for outfile\n");
@@ -341,13 +287,14 @@ dsaparam_main(int argc, char **argv)
  end:
 	BIO_free(in);
 	BIO_free_all(out);
+	BN_GENCB_free(cb);
 	DSA_free(dsa);
 
 	return (ret);
 }
 
 static int
-dsa_cb(int p, int n, BN_GENCB * cb)
+dsa_cb(int p, int n, BN_GENCB *cb)
 {
 	char c = '*';
 
@@ -359,8 +306,8 @@ dsa_cb(int p, int n, BN_GENCB * cb)
 		c = '*';
 	if (p == 3)
 		c = '\n';
-	BIO_write(cb->arg, &c, 1);
-	(void) BIO_flush(cb->arg);
+	BIO_write(BN_GENCB_get_arg(cb), &c, 1);
+	(void) BIO_flush(BN_GENCB_get_arg(cb));
 #ifdef GENCB_TEST
 	if (stop_keygen_flag)
 		return 0;
