@@ -1,4 +1,4 @@
-/* $OpenBSD: bn_recp.c,v 1.19 2023/03/27 10:25:02 tb Exp $ */
+/* $OpenBSD: bn_recp.c,v 1.34 2025/05/10 05:54:38 tb Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -58,30 +58,38 @@
 
 #include <stdio.h>
 
-#include <openssl/err.h>
-
 #include "bn_local.h"
+#include "err_local.h"
 
-void
-BN_RECP_CTX_init(BN_RECP_CTX *recp)
-{
-	BN_init(&(recp->N));
-	BN_init(&(recp->Nr));
-	recp->num_bits = 0;
-	recp->flags = 0;
-}
+struct bn_recp_ctx_st {
+	BIGNUM *N;	/* the divisor */
+	BIGNUM *Nr;	/* the reciprocal 2^shift / N */
+	int num_bits;	/* number of bits in N */
+	int shift;
+} /* BN_RECP_CTX */;
 
 BN_RECP_CTX *
-BN_RECP_CTX_new(void)
+BN_RECP_CTX_create(const BIGNUM *N)
 {
-	BN_RECP_CTX *ret;
+	BN_RECP_CTX *recp;
 
-	if ((ret = malloc(sizeof(BN_RECP_CTX))) == NULL)
-		return (NULL);
+	if ((recp = calloc(1, sizeof(*recp))) == NULL)
+		goto err;
 
-	BN_RECP_CTX_init(ret);
-	ret->flags = BN_FLG_MALLOCED;
-	return (ret);
+	if ((recp->N = BN_dup(N)) == NULL)
+		goto err;
+	BN_set_negative(recp->N, 0);
+	recp->num_bits = BN_num_bits(recp->N);
+
+	if ((recp->Nr = BN_new()) == NULL)
+		goto err;
+
+	return recp;
+
+ err:
+	BN_RECP_CTX_free(recp);
+
+	return NULL;
 }
 
 void
@@ -90,88 +98,45 @@ BN_RECP_CTX_free(BN_RECP_CTX *recp)
 	if (recp == NULL)
 		return;
 
-	BN_free(&(recp->N));
-	BN_free(&(recp->Nr));
-	if (recp->flags & BN_FLG_MALLOCED)
-		free(recp);
+	BN_free(recp->N);
+	BN_free(recp->Nr);
+	freezero(recp, sizeof(*recp));
 }
 
 int
-BN_RECP_CTX_set(BN_RECP_CTX *recp, const BIGNUM *d, BN_CTX *ctx)
-{
-	if (!bn_copy(&(recp->N), d))
-		return 0;
-	BN_zero(&(recp->Nr));
-	recp->num_bits = BN_num_bits(d);
-	recp->shift = 0;
-	return (1);
-}
-
-int
-BN_mod_mul_reciprocal(BIGNUM *r, const BIGNUM *x, const BIGNUM *y,
-    BN_RECP_CTX *recp, BN_CTX *ctx)
-{
-	int ret = 0;
-	BIGNUM *a;
-	const BIGNUM *ca;
-
-	BN_CTX_start(ctx);
-	if ((a = BN_CTX_get(ctx)) == NULL)
-		goto err;
-	if (y != NULL) {
-		if (x == y) {
-			if (!BN_sqr(a, x, ctx))
-				goto err;
-		} else {
-			if (!BN_mul(a, x, y, ctx))
-				goto err;
-		}
-		ca = a;
-	} else
-		ca = x; /* Just do the mod */
-
-	ret = BN_div_recp(NULL, r, ca, recp, ctx);
-
-err:
-	BN_CTX_end(ctx);
-	return (ret);
-}
-
-int
-BN_div_recp(BIGNUM *dv, BIGNUM *rem, const BIGNUM *m, BN_RECP_CTX *recp,
+BN_div_reciprocal(BIGNUM *dv, BIGNUM *rem, const BIGNUM *m, BN_RECP_CTX *recp,
     BN_CTX *ctx)
 {
 	int i, j, ret = 0;
 	BIGNUM *a, *b, *d, *r;
 
-	BN_CTX_start(ctx);
-	a = BN_CTX_get(ctx);
-	b = BN_CTX_get(ctx);
-	if (dv != NULL)
-		d = dv;
-	else
-		d = BN_CTX_get(ctx);
-	if (rem != NULL)
-		r = rem;
-	else
-		r = BN_CTX_get(ctx);
-	if (a == NULL || b == NULL || d == NULL || r == NULL)
-		goto err;
-
-	if (BN_ucmp(m, &(recp->N)) < 0) {
-		BN_zero(d);
-		if (!bn_copy(r, m)) {
-			BN_CTX_end(ctx);
-			return 0;
-		}
-		BN_CTX_end(ctx);
-		return (1);
+	if (BN_ucmp(m, recp->N) < 0) {
+		if (dv != NULL)
+			BN_zero(dv);
+		if (rem != NULL)
+			return bn_copy(rem, m);
+		return 1;
 	}
 
-	/* We want the remainder
-	 * Given input of ABCDEF / ab
-	 * we need multiply ABCDEF by 3 digests of the reciprocal of ab
-	 *
+	BN_CTX_start(ctx);
+	if ((a = BN_CTX_get(ctx)) == NULL)
+		goto err;
+	if ((b = BN_CTX_get(ctx)) == NULL)
+		goto err;
+
+	if ((d = dv) == NULL)
+		d = BN_CTX_get(ctx);
+	if (d == NULL)
+		goto err;
+
+	if ((r = rem) == NULL)
+		r = BN_CTX_get(ctx);
+	if (r == NULL)
+		goto err;
+
+	/*
+	 * We want the remainder. Given input of ABCDEF / ab we need to
+	 * multiply ABCDEF by 3 digits of the reciprocal of ab.
 	 */
 
 	/* i := max(BN_num_bits(m), 2*BN_num_bits(N)) */
@@ -180,28 +145,31 @@ BN_div_recp(BIGNUM *dv, BIGNUM *rem, const BIGNUM *m, BN_RECP_CTX *recp,
 	if (j > i)
 		i = j;
 
-	/* Nr := round(2^i / N) */
-	if (i != recp->shift)
-		recp->shift = BN_reciprocal(&(recp->Nr), &(recp->N), i, ctx);
+	/* Compute Nr := (1 << i) / N if necessary. */
+	if (i != recp->shift) {
+		BN_zero(recp->Nr);
+		if (!BN_set_bit(recp->Nr, i))
+			goto err;
+		if (!BN_div_ct(recp->Nr, NULL, recp->Nr, recp->N, ctx))
+			goto err;
+		recp->shift = i;
+	}
 
-	/* BN_reciprocal returns i, or -1 for an error */
-	if (recp->shift == -1)
-		goto err;
-
-	/* d := |round(round(m / 2^BN_num_bits(N)) * recp->Nr / 2^(i - BN_num_bits(N)))|
-	 *    = |round(round(m / 2^BN_num_bits(N)) * round(2^i / N) / 2^(i - BN_num_bits(N)))|
-	 *   <= |(m / 2^BN_num_bits(N)) * (2^i / N) * (2^BN_num_bits(N) / 2^i)|
-	 *    = |m/N|
+	/*
+	 * d := |((m >> BN_num_bits(N)) * recp->Nr)     >> (i - BN_num_bits(N))|
+	 *    = |((m >> BN_num_bits(N)) * (1 << i) / N) >> (i - BN_num_bits(N))|
+	 *   <= |(m / 2^BN_num_bits(N)) * (2^i / N) * 2^BN_num_bits(N) / 2^i |
+	 *    = |m / N|
 	 */
 	if (!BN_rshift(a, m, recp->num_bits))
 		goto err;
-	if (!BN_mul(b, a,&(recp->Nr), ctx))
+	if (!BN_mul(b, a, recp->Nr, ctx))
 		goto err;
 	if (!BN_rshift(d, b, i - recp->num_bits))
 		goto err;
 	d->neg = 0;
 
-	if (!BN_mul(b, &(recp->N), d, ctx))
+	if (!BN_mul(b, recp->N, d, ctx))
 		goto err;
 	if (!BN_usub(r, m, b))
 		goto err;
@@ -209,12 +177,12 @@ BN_div_recp(BIGNUM *dv, BIGNUM *rem, const BIGNUM *m, BN_RECP_CTX *recp,
 
 #if 1
 	j = 0;
-	while (BN_ucmp(r, &(recp->N)) >= 0) {
+	while (BN_ucmp(r, recp->N) >= 0) {
 		if (j++ > 2) {
 			BNerror(BN_R_BAD_RECIPROCAL);
 			goto err;
 		}
-		if (!BN_usub(r, r, &(recp->N)))
+		if (!BN_usub(r, r, recp->N))
 			goto err;
 		if (!BN_add_word(d, 1))
 			goto err;
@@ -222,39 +190,32 @@ BN_div_recp(BIGNUM *dv, BIGNUM *rem, const BIGNUM *m, BN_RECP_CTX *recp,
 #endif
 
 	BN_set_negative(r, m->neg);
-	BN_set_negative(d, m->neg ^ recp->N.neg);
+	BN_set_negative(d, m->neg ^ recp->N->neg);
 
 	ret = 1;
 
 err:
 	BN_CTX_end(ctx);
-	return (ret);
+	return ret;
 }
 
-/* len is the expected size of the result
- * We actually calculate with an extra word of precision, so
- * we can do faster division if the remainder is not required.
- */
-/* r := 2^len / m */
+/* Compute r = (x * y) % m. */
 int
-BN_reciprocal(BIGNUM *r, const BIGNUM *m, int len, BN_CTX *ctx)
+BN_mod_mul_reciprocal(BIGNUM *r, const BIGNUM *x, const BIGNUM *y,
+    BN_RECP_CTX *recp, BN_CTX *ctx)
 {
-	int ret = -1;
-	BIGNUM *t;
+	if (!BN_mul(r, x, y, ctx))
+		return 0;
 
-	BN_CTX_start(ctx);
-	if ((t = BN_CTX_get(ctx)) == NULL)
-		goto err;
+	return BN_div_reciprocal(NULL, r, r, recp, ctx);
+}
 
-	if (!BN_set_bit(t, len))
-		goto err;
+/* Compute r = x^2 % m. */
+int
+BN_mod_sqr_reciprocal(BIGNUM *r, const BIGNUM *x, BN_RECP_CTX *recp, BN_CTX *ctx)
+{
+	if (!BN_sqr(r, x, ctx))
+		return 0;
 
-	if (!BN_div_ct(r, NULL, t,m, ctx))
-		goto err;
-
-	ret = len;
-
-err:
-	BN_CTX_end(ctx);
-	return (ret);
+	return BN_div_reciprocal(NULL, r, r, recp, ctx);
 }
