@@ -1,4 +1,4 @@
-/* $OpenBSD: ec_pmeth.c,v 1.22 2024/08/26 22:01:28 op Exp $ */
+/* $OpenBSD: ec_pmeth.c,v 1.27 2025/05/10 05:54:38 tb Exp $ */
 /* Written by Dr Stephen N Henson (steve@openssl.org) for the OpenSSL
  * project 2006.
  */
@@ -62,12 +62,12 @@
 
 #include <openssl/asn1t.h>
 #include <openssl/ec.h>
-#include <openssl/err.h>
 #include <openssl/evp.h>
 #include <openssl/x509.h>
 
 #include "bn_local.h"
 #include "ec_local.h"
+#include "err_local.h"
 #include "evp_local.h"
 
 /* EC pkey context structure */
@@ -221,10 +221,8 @@ pkey_ec_derive(EVP_PKEY_CTX *ctx, unsigned char *key, size_t *keylen)
 	}
 
 	eckey = dctx->co_key ? dctx->co_key : ctx->pkey->pkey.ec;
-	if (!key) {
-		const EC_GROUP *group;
-		group = EC_KEY_get0_group(eckey);
-		*keylen = (EC_GROUP_get_degree(group) + 7) / 8;
+	if (key == NULL) {
+		*keylen = BN_num_bytes(eckey->group->p);
 		return 1;
 	}
 	pubkey = EC_KEY_get0_public_key(ctx->peerkey->pkey.ec);
@@ -236,7 +234,7 @@ pkey_ec_derive(EVP_PKEY_CTX *ctx, unsigned char *key, size_t *keylen)
 
 	outlen = *keylen;
 
-	ret = ECDH_compute_key(key, outlen, pubkey, eckey, 0);
+	ret = ECDH_compute_key(key, outlen, pubkey, eckey, NULL);
 	if (ret <= 0)
 		return 0;
 
@@ -323,7 +321,7 @@ pkey_ec_ctrl(EVP_PKEY_CTX *ctx, int type, int p1, void *p2)
 			if (!ec_key->group)
 				return -2;
 			/* If cofactor is 1 cofactor mode does nothing */
-			if (BN_is_one(&ec_key->group->cofactor))
+			if (BN_is_one(ec_key->group->cofactor))
 				return 1;
 			if (!dctx->co_key) {
 				dctx->co_key = EC_KEY_dup(ec_key);
@@ -381,16 +379,19 @@ pkey_ec_ctrl(EVP_PKEY_CTX *ctx, int type, int p1, void *p2)
 
 	case EVP_PKEY_CTRL_MD:
 		/* RFC 3279, RFC 5758 and NIST CSOR. */
-		if (EVP_MD_type((const EVP_MD *) p2) != NID_sha1 &&
-		    EVP_MD_type((const EVP_MD *) p2) != NID_ecdsa_with_SHA1 &&
-		    EVP_MD_type((const EVP_MD *) p2) != NID_sha224 &&
-		    EVP_MD_type((const EVP_MD *) p2) != NID_sha256 &&
-		    EVP_MD_type((const EVP_MD *) p2) != NID_sha384 &&
-		    EVP_MD_type((const EVP_MD *) p2) != NID_sha512 &&
-		    EVP_MD_type((const EVP_MD *) p2) != NID_sha3_224 &&
-		    EVP_MD_type((const EVP_MD *) p2) != NID_sha3_256 &&
-		    EVP_MD_type((const EVP_MD *) p2) != NID_sha3_384 &&
-		    EVP_MD_type((const EVP_MD *) p2) != NID_sha3_512) {
+		switch (EVP_MD_type(p2)) {
+		case NID_sha1:
+		case NID_ecdsa_with_SHA1:
+		case NID_sha224:
+		case NID_sha256:
+		case NID_sha384:
+		case NID_sha512:
+		case NID_sha3_224:
+		case NID_sha3_256:
+		case NID_sha3_384:
+		case NID_sha3_512:
+			break;
+		default:
 			ECerror(EC_R_INVALID_DIGEST_TYPE);
 			return 0;
 		}
