@@ -1,4 +1,4 @@
-/* $OpenBSD: ts_rsp_utils.c,v 1.6 2017/01/29 17:49:23 beck Exp $ */
+/* $OpenBSD: ts_rsp_utils.c,v 1.12 2025/05/10 05:54:39 tb Exp $ */
 /* Written by Zoltan Glozik (zglozik@stones.com) for the OpenSSL
  * project 2002.
  */
@@ -58,11 +58,13 @@
 
 #include <stdio.h>
 
-#include <openssl/err.h>
 #include <openssl/objects.h>
 #include <openssl/pkcs7.h>
 #include <openssl/ts.h>
 
+#include "err_local.h"
+#include "ts_local.h"
+
 /* Function definitions. */
 
 int
@@ -82,12 +84,42 @@ TS_RESP_set_status_info(TS_RESP *a, TS_STATUS_INFO *status_info)
 
 	return 1;
 }
+LCRYPTO_ALIAS(TS_RESP_set_status_info);
 
 TS_STATUS_INFO *
 TS_RESP_get_status_info(TS_RESP *a)
 {
 	return a->status_info;
 }
+LCRYPTO_ALIAS(TS_RESP_get_status_info);
+
+const ASN1_UTF8STRING *
+TS_STATUS_INFO_get0_failure_info(const TS_STATUS_INFO *si)
+{
+	return si->failure_info;
+}
+LCRYPTO_ALIAS(TS_STATUS_INFO_get0_failure_info);
+
+const STACK_OF(ASN1_UTF8STRING) *
+TS_STATUS_INFO_get0_text(const TS_STATUS_INFO *si)
+{
+	return si->text;
+}
+LCRYPTO_ALIAS(TS_STATUS_INFO_get0_text);
+
+const ASN1_INTEGER *
+TS_STATUS_INFO_get0_status(const TS_STATUS_INFO *si)
+{
+	return si->status;
+}
+LCRYPTO_ALIAS(TS_STATUS_INFO_get0_status);
+
+int
+TS_STATUS_INFO_set_status(TS_STATUS_INFO *si, int i)
+{
+	return ASN1_INTEGER_set(si->status, i);
+}
+LCRYPTO_ALIAS(TS_STATUS_INFO_set_status);
 
 /* Caller loses ownership of PKCS7 and TS_TST_INFO objects. */
 void
@@ -99,30 +131,35 @@ TS_RESP_set_tst_info(TS_RESP *a, PKCS7 *p7, TS_TST_INFO *tst_info)
 	TS_TST_INFO_free(a->tst_info);
 	a->tst_info = tst_info;
 }
+LCRYPTO_ALIAS(TS_RESP_set_tst_info);
 
 PKCS7 *
 TS_RESP_get_token(TS_RESP *a)
 {
 	return a->token;
 }
+LCRYPTO_ALIAS(TS_RESP_get_token);
 
 TS_TST_INFO *
 TS_RESP_get_tst_info(TS_RESP *a)
 {
 	return a->tst_info;
 }
+LCRYPTO_ALIAS(TS_RESP_get_tst_info);
 
 int
 TS_TST_INFO_set_version(TS_TST_INFO *a, long version)
 {
 	return ASN1_INTEGER_set(a->version, version);
 }
+LCRYPTO_ALIAS(TS_TST_INFO_set_version);
 
 long
 TS_TST_INFO_get_version(const TS_TST_INFO *a)
 {
 	return ASN1_INTEGER_get(a->version);
 }
+LCRYPTO_ALIAS(TS_TST_INFO_get_version);
 
 int
 TS_TST_INFO_set_policy_id(TS_TST_INFO *a, ASN1_OBJECT *policy)
@@ -140,12 +177,14 @@ TS_TST_INFO_set_policy_id(TS_TST_INFO *a, ASN1_OBJECT *policy)
 	a->policy_id = new_policy;
 	return 1;
 }
+LCRYPTO_ALIAS(TS_TST_INFO_set_policy_id);
 
 ASN1_OBJECT *
 TS_TST_INFO_get_policy_id(TS_TST_INFO *a)
 {
 	return a->policy_id;
 }
+LCRYPTO_ALIAS(TS_TST_INFO_get_policy_id);
 
 int
 TS_TST_INFO_set_msg_imprint(TS_TST_INFO *a, TS_MSG_IMPRINT *msg_imprint)
@@ -163,12 +202,14 @@ TS_TST_INFO_set_msg_imprint(TS_TST_INFO *a, TS_MSG_IMPRINT *msg_imprint)
 	a->msg_imprint = new_msg_imprint;
 	return 1;
 }
+LCRYPTO_ALIAS(TS_TST_INFO_set_msg_imprint);
 
 TS_MSG_IMPRINT *
 TS_TST_INFO_get_msg_imprint(TS_TST_INFO *a)
 {
 	return a->msg_imprint;
 }
+LCRYPTO_ALIAS(TS_TST_INFO_get_msg_imprint);
 
 int
 TS_TST_INFO_set_serial(TS_TST_INFO *a, const ASN1_INTEGER *serial)
@@ -186,12 +227,14 @@ TS_TST_INFO_set_serial(TS_TST_INFO *a, const ASN1_INTEGER *serial)
 	a->serial = new_serial;
 	return 1;
 }
+LCRYPTO_ALIAS(TS_TST_INFO_set_serial);
 
 const ASN1_INTEGER *
 TS_TST_INFO_get_serial(const TS_TST_INFO *a)
 {
 	return a->serial;
 }
+LCRYPTO_ALIAS(TS_TST_INFO_get_serial);
 
 int
 TS_TST_INFO_set_time(TS_TST_INFO *a, const ASN1_GENERALIZEDTIME *gtime)
@@ -209,12 +252,14 @@ TS_TST_INFO_set_time(TS_TST_INFO *a, const ASN1_GENERALIZEDTIME *gtime)
 	a->time = new_time;
 	return 1;
 }
+LCRYPTO_ALIAS(TS_TST_INFO_set_time);
 
 const ASN1_GENERALIZEDTIME *
 TS_TST_INFO_get_time(const TS_TST_INFO *a)
 {
 	return a->time;
 }
+LCRYPTO_ALIAS(TS_TST_INFO_get_time);
 
 int
 TS_TST_INFO_set_accuracy(TS_TST_INFO *a, TS_ACCURACY *accuracy)
@@ -232,12 +277,14 @@ TS_TST_INFO_set_accuracy(TS_TST_INFO *a, TS_ACCURACY *accuracy)
 	a->accuracy = new_accuracy;
 	return 1;
 }
+LCRYPTO_ALIAS(TS_TST_INFO_set_accuracy);
 
 TS_ACCURACY *
 TS_TST_INFO_get_accuracy(TS_TST_INFO *a)
 {
 	return a->accuracy;
 }
+LCRYPTO_ALIAS(TS_TST_INFO_get_accuracy);
 
 int
 TS_ACCURACY_set_seconds(TS_ACCURACY *a, const ASN1_INTEGER *seconds)
@@ -255,12 +302,14 @@ TS_ACCURACY_set_seconds(TS_ACCURACY *a, const ASN1_INTEGER *seconds)
 	a->seconds = new_seconds;
 	return 1;
 }
+LCRYPTO_ALIAS(TS_ACCURACY_set_seconds);
 
 const ASN1_INTEGER *
 TS_ACCURACY_get_seconds(const TS_ACCURACY *a)
 {
 	return a->seconds;
 }
+LCRYPTO_ALIAS(TS_ACCURACY_get_seconds);
 
 int
 TS_ACCURACY_set_millis(TS_ACCURACY *a, const ASN1_INTEGER *millis)
@@ -280,12 +329,14 @@ TS_ACCURACY_set_millis(TS_ACCURACY *a, const ASN1_INTEGER *millis)
 	a->millis = new_millis;
 	return 1;
 }
+LCRYPTO_ALIAS(TS_ACCURACY_set_millis);
 
 const ASN1_INTEGER *
 TS_ACCURACY_get_millis(const TS_ACCURACY *a)
 {
 	return a->millis;
 }
+LCRYPTO_ALIAS(TS_ACCURACY_get_millis);
 
 int
 TS_ACCURACY_set_micros(TS_ACCURACY *a, const ASN1_INTEGER *micros)
@@ -305,12 +356,14 @@ TS_ACCURACY_set_micros(TS_ACCURACY *a, const ASN1_INTEGER *micros)
 	a->micros = new_micros;
 	return 1;
 }
+LCRYPTO_ALIAS(TS_ACCURACY_set_micros);
 
 const ASN1_INTEGER *
 TS_ACCURACY_get_micros(const TS_ACCURACY *a)
 {
 	return a->micros;
 }
+LCRYPTO_ALIAS(TS_ACCURACY_get_micros);
 
 int
 TS_TST_INFO_set_ordering(TS_TST_INFO *a, int ordering)
@@ -318,12 +371,14 @@ TS_TST_INFO_set_ordering(TS_TST_INFO *a, int ordering)
 	a->ordering = ordering ? 0xFF : 0x00;
 	return 1;
 }
+LCRYPTO_ALIAS(TS_TST_INFO_set_ordering);
 
 int
 TS_TST_INFO_get_ordering(const TS_TST_INFO *a)
 {
 	return a->ordering ? 1 : 0;
 }
+LCRYPTO_ALIAS(TS_TST_INFO_get_ordering);
 
 int
 TS_TST_INFO_set_nonce(TS_TST_INFO *a, const ASN1_INTEGER *nonce)
@@ -341,12 +396,14 @@ TS_TST_INFO_set_nonce(TS_TST_INFO *a, const ASN1_INTEGER *nonce)
 	a->nonce = new_nonce;
 	return 1;
 }
+LCRYPTO_ALIAS(TS_TST_INFO_set_nonce);
 
 const ASN1_INTEGER *
 TS_TST_INFO_get_nonce(const TS_TST_INFO *a)
 {
 	return a->nonce;
 }
+LCRYPTO_ALIAS(TS_TST_INFO_get_nonce);
 
 int
 TS_TST_INFO_set_tsa(TS_TST_INFO *a, GENERAL_NAME *tsa)
@@ -364,17 +421,20 @@ TS_TST_INFO_set_tsa(TS_TST_INFO *a, GENERAL_NAME *tsa)
 	a->tsa = new_tsa;
 	return 1;
 }
+LCRYPTO_ALIAS(TS_TST_INFO_set_tsa);
 
 GENERAL_NAME *
 TS_TST_INFO_get_tsa(TS_TST_INFO *a)
 {
 	return a->tsa;
 }
+LCRYPTO_ALIAS(TS_TST_INFO_get_tsa);
 
 STACK_OF(X509_EXTENSION) *TS_TST_INFO_get_exts(TS_TST_INFO *a)
 {
 	return a->extensions;
 }
+LCRYPTO_ALIAS(TS_TST_INFO_get_exts);
 
 void
 TS_TST_INFO_ext_free(TS_TST_INFO *a)
@@ -384,51 +444,60 @@ TS_TST_INFO_ext_free(TS_TST_INFO *a)
 	sk_X509_EXTENSION_pop_free(a->extensions, X509_EXTENSION_free);
 	a->extensions = NULL;
 }
+LCRYPTO_ALIAS(TS_TST_INFO_ext_free);
 
 int
 TS_TST_INFO_get_ext_count(TS_TST_INFO *a)
 {
 	return X509v3_get_ext_count(a->extensions);
 }
+LCRYPTO_ALIAS(TS_TST_INFO_get_ext_count);
 
 int
 TS_TST_INFO_get_ext_by_NID(TS_TST_INFO *a, int nid, int lastpos)
 {
 	return X509v3_get_ext_by_NID(a->extensions, nid, lastpos);
 }
+LCRYPTO_ALIAS(TS_TST_INFO_get_ext_by_NID);
 
 int
-TS_TST_INFO_get_ext_by_OBJ(TS_TST_INFO *a, ASN1_OBJECT *obj, int lastpos)
+TS_TST_INFO_get_ext_by_OBJ(TS_TST_INFO *a, const ASN1_OBJECT *obj, int lastpos)
 {
 	return X509v3_get_ext_by_OBJ(a->extensions, obj, lastpos);
 }
+LCRYPTO_ALIAS(TS_TST_INFO_get_ext_by_OBJ);
 
 int
 TS_TST_INFO_get_ext_by_critical(TS_TST_INFO *a, int crit, int lastpos)
 {
 	return X509v3_get_ext_by_critical(a->extensions, crit, lastpos);
 }
+LCRYPTO_ALIAS(TS_TST_INFO_get_ext_by_critical);
 
 X509_EXTENSION *
 TS_TST_INFO_get_ext(TS_TST_INFO *a, int loc)
 {
 	return X509v3_get_ext(a->extensions, loc);
 }
+LCRYPTO_ALIAS(TS_TST_INFO_get_ext);
 
 X509_EXTENSION *
 TS_TST_INFO_delete_ext(TS_TST_INFO *a, int loc)
 {
 	return X509v3_delete_ext(a->extensions, loc);
 }
+LCRYPTO_ALIAS(TS_TST_INFO_delete_ext);
 
 int
 TS_TST_INFO_add_ext(TS_TST_INFO *a, X509_EXTENSION *ex, int loc)
 {
 	return X509v3_add_ext(&a->extensions, ex, loc) != NULL;
 }
+LCRYPTO_ALIAS(TS_TST_INFO_add_ext);
 
 void *
 TS_TST_INFO_get_ext_d2i(TS_TST_INFO *a, int nid, int *crit, int *idx)
 {
 	return X509V3_get_d2i(a->extensions, nid, crit, idx);
 }
+LCRYPTO_ALIAS(TS_TST_INFO_get_ext_d2i);
