@@ -1,4 +1,4 @@
-/* $OpenBSD: ts_rsp_verify.c,v 1.28 2022/07/24 08:16:47 tb Exp $ */
+/* $OpenBSD: ts_rsp_verify.c,v 1.31 2025/05/10 05:54:39 tb Exp $ */
 /* Written by Zoltan Glozik (zglozik@stones.com) for the OpenSSL
  * project 2002.
  */
@@ -59,14 +59,14 @@
 #include <stdio.h>
 #include <string.h>
 
-#include <openssl/err.h>
 #include <openssl/objects.h>
 #include <openssl/pkcs7.h>
 #include <openssl/ts.h>
 
-#include "evp_locl.h"
+#include "err_local.h"
+#include "evp_local.h"
 #include "ts_local.h"
-#include "x509_lcl.h"
+#include "x509_local.h"
 
 /* Private function declarations. */
 
@@ -230,6 +230,7 @@ err:
 
 	return ret;
 }
+LCRYPTO_ALIAS(TS_RESP_verify_signature);
 
 /*
  * The certificate chain is returned in chain. Caller is responsible for
@@ -485,6 +486,7 @@ TS_RESP_verify_response(TS_VERIFY_CTX *ctx, TS_RESP *response)
 err:
 	return ret;
 }
+LCRYPTO_ALIAS(TS_RESP_verify_response);
 
 /*
  * Tries to extract a TS_TST_INFO structure from the PKCS7 token and
@@ -502,6 +504,7 @@ TS_RESP_verify_token(TS_VERIFY_CTX *ctx, PKCS7 *token)
 	}
 	return ret;
 }
+LCRYPTO_ALIAS(TS_RESP_verify_token);
 
 /*
  * Verifies whether the 'token' contains a valid time stamp token
