@@ -4,10 +4,14 @@
  */
 
 #ifdef _MSC_VER
-#if _MSC_VER >= 1900
-#include <../ucrt/limits.h>
-#else
 #include <../include/limits.h>
+#if _MSC_VER >= 1900
+#include <../ucrt/stdlib.h>
+#else
+#include <../include/stdlib.h>
+#endif
+#ifndef PATH_MAX
+#define PATH_MAX _MAX_PATH
 #endif
 #else
 #include_next <limits.h>
