@@ -8,6 +8,24 @@
 
 #ifndef _MSC_VER
 #include_next <sys/stat.h>
+
+/* for old MinGW */
+#ifndef S_IRWXU
+#define S_IRWXU         0
+#endif
+#ifndef S_IRWXG
+#define S_IRWXG         0
+#endif
+#ifndef S_IRGRP
+#define S_IRGRP         0
+#endif
+#ifndef S_IRWXO
+#define S_IRWXO         0
+#endif
+#ifndef S_IROTH
+#define S_IROTH         0
+#endif
+
 #else
 
 #include <windows.h>
@@ -56,12 +74,15 @@
 #endif
 
 #if defined(_MSC_VER)
+#   define S_IRWXU  0                           /* RWX user */
 #   define S_IRUSR  S_IREAD                     /* Read user */
 #   define S_IWUSR  S_IWRITE                    /* Write user */
 #   define S_IXUSR  0                           /* Execute user */
+#   define S_IRWXG  0                           /* RWX group */
 #   define S_IRGRP  0                           /* Read group */
 #   define S_IWGRP  0                           /* Write group */
 #   define S_IXGRP  0                           /* Execute group */
+#   define S_IRWXO  0                           /* RWX others */
 #   define S_IROTH  0                           /* Read others */
 #   define S_IWOTH  0                           /* Write others */
 #   define S_IXOTH  0                           /* Execute others */
@@ -97,4 +118,12 @@
 
 #endif
 
+#ifdef _WIN32
+int libressl_fstat(int fd, struct stat *statbuf);
+
+#ifndef NO_REDEF_POSIX_FUNCTIONS
+#define fstat(fd, statbuf) libressl_fstat(fd, statbuf)
+#endif
+#endif
+
 #endif
