@@ -1,4 +1,4 @@
-/*	$OpenBSD: bytestring.h,v 1.24 2022/11/09 23:14:51 jsing Exp $	*/
+/*	$OpenBSD: bytestring.h,v 1.26 2024/12/05 19:57:37 tb Exp $	*/
 /*
  * Copyright (c) 2014, Google Inc.
  *
@@ -459,6 +459,13 @@ int CBB_add_u16_length_prefixed(CBB *cbb, CBB *out_contents);
  */
 int CBB_add_u24_length_prefixed(CBB *cbb, CBB *out_contents);
 
+/*
+ * CBB_add_u32_length_prefixed sets |*out_contents| to a new child of |cbb|.
+ * The data written to |*out_contents| will be prefixed in |cbb| with a 32-bit,
+ * big-endian length. It returns one on success or zero on error.
+ */
+int CBB_add_u32_length_prefixed(CBB *cbb, CBB *out_contents);
+
 /*
  * CBB_add_asn sets |*out_contents| to a |CBB| into which the contents of an
  * ASN.1 object can be written. The |tag| argument will be used as the tag for
@@ -559,6 +566,6 @@ int cbs_get_any_asn1_element_internal(CBS *cbs, CBS *out, unsigned int *out_tag,
 int CBS_asn1_indefinite_to_definite(CBS *in, uint8_t **out, size_t *out_len);
 #endif /* LIBRESSL_INTERNAL */
 
-__END_HIDDEN_DECLS 
+__END_HIDDEN_DECLS
 
 #endif  /* OPENSSL_HEADER_BYTESTRING_H */
