@@ -1,4 +1,4 @@
-/*	$OpenBSD: asn1test.c,v 1.8 2021/06/30 18:09:46 jsing Exp $	*/
+/*	$OpenBSD: asn1test.c,v 1.13 2024/07/22 14:50:45 jsing Exp $	*/
 /*
  * Copyright (c) 2014, 2016 Joel Sing <jsing@openbsd.org>
  *
@@ -23,7 +23,7 @@
 #include <openssl/ssl.h>
 #include <openssl/tls1.h>
 
-#include "ssl_locl.h"
+#include "ssl_local.h"
 
 int i2d_SSL_SESSION(SSL_SESSION *in, unsigned char **pp);
 SSL_SESSION *d2i_SSL_SESSION(SSL_SESSION **a, const unsigned char **pp,
@@ -82,7 +82,7 @@ unsigned char tlsext_tick[] = {
 struct ssl_asn1_test ssl_asn1_tests[] = {
 	{
 		.session = {
-			.cipher_id = 0x03000000L | 1,
+			.cipher_value = 1,
 			.ssl_version = TLS1_2_VERSION,
 		},
 		.asn1 = {
@@ -94,7 +94,7 @@ struct ssl_asn1_test ssl_asn1_tests[] = {
 	},
 	{
 		.session = {
-			.cipher_id = 0x03000000L | 1,
+			.cipher_value = 1,
 			.ssl_version = TLS1_2_VERSION,
 			.master_key_length = 26,
 			.session_id = "0123456789",
@@ -119,7 +119,7 @@ struct ssl_asn1_test ssl_asn1_tests[] = {
 	},
 	{
 		.session = {
-			.cipher_id = 0x03000000L | 1,
+			.cipher_value = 1,
 			.ssl_version = TLS1_2_VERSION,
 			.master_key_length = 26,
 			.session_id = "0123456789",
@@ -232,7 +232,7 @@ struct ssl_asn1_test ssl_asn1_tests[] = {
 	},
 	{
 		.session = {
-			.cipher_id = 0x03000000L | 1,
+			.cipher_value = 1,
 			.ssl_version = TLS1_2_VERSION,
 			.timeout = -1,
 		},
@@ -243,7 +243,7 @@ struct ssl_asn1_test ssl_asn1_tests[] = {
 	},
 	{
 		.session = {
-			.cipher_id = 0x03000000L | 1,
+			.cipher_value = 1,
 			.ssl_version = TLS1_2_VERSION,
 			.time = -1,
 		},
@@ -272,18 +272,18 @@ session_cmp(SSL_SESSION *s1, SSL_SESSION *s2)
 {
 	/* Compare the ASN.1 encoded values from two sessions. */
 	if (s1->ssl_version != s2->ssl_version) {
-		fprintf(stderr, "ssl_version differs: %i != %i\n",
+		fprintf(stderr, "ssl_version differs: %d != %d\n",
 		    s1->ssl_version, s2->ssl_version);
 		return (1);
 	}
-	if (s1->cipher_id != s2->cipher_id) {
-		fprintf(stderr, "cipher_id differs: %li != %li\n",
-		    s1->cipher_id, s2->cipher_id);
+	if (s1->cipher_value != s2->cipher_value) {
+		fprintf(stderr, "cipher_value differs: %d != %d\n",
+		    s1->cipher_value, s2->cipher_value);
 		return (1);
 	}
 
 	if (s1->master_key_length != s2->master_key_length) {
-		fprintf(stderr, "master_key_length differs: %i != %i\n",
+		fprintf(stderr, "master_key_length differs: %zu != %zu\n",
 		    s1->master_key_length, s2->master_key_length);
 		return (1);
 	}
@@ -294,7 +294,7 @@ session_cmp(SSL_SESSION *s1, SSL_SESSION *s2)
 	}
 
 	if (s1->session_id_length != s2->session_id_length) {
-		fprintf(stderr, "session_id_length differs: %i != %i\n",
+		fprintf(stderr, "session_id_length differs: %zu != %zu\n",
 		    s1->session_id_length, s2->session_id_length);
 		return (1);
 	}
@@ -305,7 +305,7 @@ session_cmp(SSL_SESSION *s1, SSL_SESSION *s2)
 	}
 
 	if (s1->sid_ctx_length != s2->sid_ctx_length) {
-		fprintf(stderr, "sid_ctx_length differs: %i != %i\n",
+		fprintf(stderr, "sid_ctx_length differs: %zu != %zu\n",
 		    s1->sid_ctx_length, s2->sid_ctx_length);
 		return (1);
 	}
@@ -317,28 +317,28 @@ session_cmp(SSL_SESSION *s1, SSL_SESSION *s2)
 
 	/* d2i_SSL_SESSION uses the current time if decoding a zero value. */
 	if ((s1->time != s2->time) && s1->time != 0 && s2->time != 0) {
-		fprintf(stderr, "time differs: %lli != %lli\n",
+		fprintf(stderr, "time differs: %lld != %lld\n",
 		    (long long)s1->time, (long long)s2->time);
 		return (1);
 	}
 	/* d2i_SSL_SESSION uses a timeout of 3 if decoding a zero value. */
 	if ((s1->timeout != s2->timeout) &&
 	    s1->timeout != 3 && s2->timeout != 3) {
-		fprintf(stderr, "timeout differs: %li != %li\n",
+		fprintf(stderr, "timeout differs: %ld != %ld\n",
 		    s1->timeout, s2->timeout);
 		return (1);
 	}
 
 	/* Ensure that a certificate is or is not present in both. */
-	if ((s1->peer != NULL || s2->peer != NULL) &&
-	    (s1->peer == NULL || s2->peer == NULL ||
-	     X509_cmp(s1->peer, s2->peer) != 0)) {
-		fprintf(stderr, "peer differs\n");
+	if ((s1->peer_cert != NULL || s2->peer_cert != NULL) &&
+	    (s1->peer_cert == NULL || s2->peer_cert == NULL ||
+	     X509_cmp(s1->peer_cert, s2->peer_cert) != 0)) {
+		fprintf(stderr, "peer_cert differs\n");
 		return (1);
 	}
 
 	if (s1->verify_result != s2->verify_result) {
-		fprintf(stderr, "verify_result differs: %li != %li\n",
+		fprintf(stderr, "verify_result differs: %ld != %ld\n",
 		    s1->verify_result, s2->verify_result);
 		return (1);
 	}
@@ -350,7 +350,7 @@ session_cmp(SSL_SESSION *s1, SSL_SESSION *s2)
 	}
 	if (s1->tlsext_tick_lifetime_hint != s2->tlsext_tick_lifetime_hint) {
 		fprintf(stderr, "tlsext_tick_lifetime_hint differs: "
-		    "%li != %li\n", s1->tlsext_tick_lifetime_hint,
+		    "%u != %u\n", s1->tlsext_tick_lifetime_hint,
 		    s2->tlsext_tick_lifetime_hint);
 		return (1);
 	}
@@ -377,12 +377,12 @@ do_ssl_asn1_test(int test_no, struct ssl_asn1_test *sat)
 	int i, len, rv = 1;
 
 	if (sat->peer_cert)
-		sat->session.peer = peer_cert;
+		sat->session.peer_cert = peer_cert;
 
 	len = i2d_SSL_SESSION(&sat->session, NULL);
 	if (len != sat->asn1_len) {
-		fprintf(stderr, "FAIL: test %i returned ASN1 length %i, "
-		    "want %i\n", test_no, len, sat->asn1_len);
+		fprintf(stderr, "FAIL: test %d returned ASN1 length %d, "
+		    "want %d\n", test_no, len, sat->asn1_len);
 		goto failed;
 	}
 
@@ -398,19 +398,19 @@ do_ssl_asn1_test(int test_no, struct ssl_asn1_test *sat)
 
 	/* Check the length again since the code path is different. */
 	if (len != sat->asn1_len) {
-		fprintf(stderr, "FAIL: test %i returned ASN1 length %i, "
-		    "want %i\n", test_no, len, sat->asn1_len);
+		fprintf(stderr, "FAIL: test %d returned ASN1 length %d, "
+		    "want %d\n", test_no, len, sat->asn1_len);
 		goto failed;
 	}
 	/* ap should now point at the end of the buffer. */
 	if (ap - asn1 != len) {
-		fprintf(stderr, "FAIL: test %i pointer increment does not "
-		    "match length (%i != %i)\n", test_no, (int)(ap - asn1), len);
+		fprintf(stderr, "FAIL: test %d pointer increment does not "
+		    "match length (%d != %d)\n", test_no, (int)(ap - asn1), len);
 		goto failed;
 	}
 
 	if (memcmp(asn1, &sat->asn1, len) != 0) {
-		fprintf(stderr, "FAIL: test %i - encoding differs:\n", test_no);
+		fprintf(stderr, "FAIL: test %d - encoding differs:\n", test_no);
 		fprintf(stderr, "encoding:\n");
 		for (i = 1; i <= len; i++) {
 			fprintf(stderr, " 0x%02hhx,", asn1[i - 1]);
@@ -431,12 +431,12 @@ do_ssl_asn1_test(int test_no, struct ssl_asn1_test *sat)
 	pp = sat->asn1;
 
 	if ((sp = d2i_SSL_SESSION(NULL, &pp, sat->asn1_len)) == NULL) {
-		fprintf(stderr, "FAIL: test %i - decoding failed\n", test_no);
+		fprintf(stderr, "FAIL: test %d - decoding failed\n", test_no);
 		goto failed;
 	}
 
 	if (session_cmp(sp, &sat->session) != 0) {
-		fprintf(stderr, "FAIL: test %i - decoding differs\n", test_no);
+		fprintf(stderr, "FAIL: test %d - decoding differs\n", test_no);
 		goto failed;
 	}
 
