@@ -1,4 +1,4 @@
-/*	$OpenBSD: handshake_table.c,v 1.17 2022/03/08 16:59:25 tb Exp $	*/
+/*	$OpenBSD: handshake_table.c,v 1.18 2022/12/01 13:49:12 tb Exp $	*/
 /*
  * Copyright (c) 2019 Theo Buehler <tb@openbsd.org>
  *
@@ -518,7 +518,6 @@ main(int argc, char *argv[])
 	unsigned int	depth = 0;
 	int		ch, graphviz = 0, print = 0;
 
-#ifndef _MSC_VER
 	while ((ch = getopt(argc, argv, "Cg")) != -1) {
 		switch (ch) {
 		case 'C':
@@ -536,7 +535,6 @@ main(int argc, char *argv[])
 
 	if (argc != 0)
 		usage();
-#endif
 
 	if (graphviz && print)
 		usage();
@@ -548,8 +546,5 @@ main(int argc, char *argv[])
 	if (!verify_table(hs_table, print))
 		return 1;
 
-	if (!print)
-		printf("SUCCESS\n");
-
 	return 0;
 }
