@@ -1,4 +1,4 @@
-/* $OpenBSD: policy.c,v 1.10 2023/04/28 16:50:16 beck Exp $ */
+/* $OpenBSD: policy.c,v 1.13 2024/08/23 12:56:26 anton Exp $ */
 /*
  * Copyright (c) 2020 Joel Sing <jsing@openbsd.org>
  * Copyright (c) 2020-2023 Bob Beck <beck@openbsd.org>
@@ -182,7 +182,7 @@ verify_cert(const char *roots_file, const char *intermediate_file,
 	}
 
 	if (*error == 0)
-		errx(1, "Error unset on failure!\n");
+		errx(1, "Error unset on failure!");
 
 	fprintf(stderr, "failed to verify at %d: %s\n",
 	    *error_depth, X509_verify_cert_error_string(*error));
@@ -279,7 +279,7 @@ struct verify_cert_test verify_cert_tests[] = {
 	},
 	/*  The policy extension cannot be parsed. */
 	{
-		.id = "1 in invalid intermediate poicy",
+		.id = "1 in invalid intermediate policy",
 		.root_file = CERTSDIR "/" "policy_root.pem",
 		.intermediate_file = CERTSDIR "/" "policy_intermediate_invalid.pem",
 		.leaf_file = CERTSDIR "/" "policy_leaf.pem",
@@ -558,9 +558,13 @@ struct verify_cert_test verify_cert_tests[] = {
 		.root_file = CERTSDIR "/" "policy_root.pem",
 		.intermediate_file = CERTSDIR "/" "policy_intermediate.pem",
 		.leaf_file = CERTSDIR "/" "policy_leaf_any.pem",
-		.policy_oid_to_check = OID1,
+		.policy_oid_to_check = OID3,
 		.verify_flags = X509_V_FLAG_EXPLICIT_POLICY,
-		.want_chains = 1,
+		.want_chains = 0,
+		.want_error = X509_V_ERR_NO_EXPLICIT_POLICY,
+		.want_error_depth = 0,
+		.want_legacy_error = X509_V_ERR_NO_EXPLICIT_POLICY,
+		.want_legacy_error_depth = 0,
 	},
 	/* Both assert anyPolicy. All policies are valid. */
 	{
