@@ -1,4 +1,4 @@
-/*	$OpenBSD: rfc3779.c,v 1.6 2022/01/07 22:46:05 tb Exp $ */
+/*	$OpenBSD: rfc3779.c,v 1.10 2023/12/13 07:19:37 tb Exp $ */
 /*
  * Copyright (c) 2021 Theo Buehler <tb@openbsd.org>
  *
@@ -322,7 +322,7 @@ run_IPAddressOrRange_tests(void)
  */
 static IPAddrBlocks *IPAddrBlocks_new(void);
 static void IPAddrBlocks_free(IPAddrBlocks *addr);
-static __unused IPAddrBlocks *d2i_IPAddrBlocks(IPAddrBlocks **addrs,
+static IPAddrBlocks *d2i_IPAddrBlocks(IPAddrBlocks **addrs,
     const unsigned char **in, long len);
 static int i2d_IPAddrBlocks(IPAddrBlocks *addrs, unsigned char **out);
 
@@ -361,10 +361,10 @@ IPAddrBlocks_free(IPAddrBlocks *addr)
  * extensions on each call.
  */
 
-static const ASN1_ITEM_EXP *
+static ASN1_ITEM_EXP *
 get_IPAddrBlocks_it(void)
 {
-	static const ASN1_ITEM_EXP *my_IPAddrBlocks_it;
+	static ASN1_ITEM_EXP *my_IPAddrBlocks_it;
 	const X509V3_EXT_METHOD *v3_addr;
 
 	if (my_IPAddrBlocks_it != NULL)
@@ -380,10 +380,10 @@ get_IPAddrBlocks_it(void)
 	return my_IPAddrBlocks_it;
 }
 
-static __unused IPAddrBlocks *
+static IPAddrBlocks *
 d2i_IPAddrBlocks(IPAddrBlocks **addrs, const unsigned char **in, long len)
 {
-	const ASN1_ITEM_EXP *my_IPAddrBlocks_it;
+	ASN1_ITEM_EXP *my_IPAddrBlocks_it;
 
 	if ((my_IPAddrBlocks_it = get_IPAddrBlocks_it()) == NULL)
 		return NULL;
@@ -395,7 +395,7 @@ d2i_IPAddrBlocks(IPAddrBlocks **addrs, const unsigned char **in, long len)
 static int
 i2d_IPAddrBlocks(IPAddrBlocks *addrs, unsigned char **out)
 {
-	const ASN1_ITEM_EXP *my_IPAddrBlocks_it;
+	ASN1_ITEM_EXP *my_IPAddrBlocks_it;
 
 	if ((my_IPAddrBlocks_it = get_IPAddrBlocks_it()) == NULL)
 		return -1;
@@ -867,12 +867,13 @@ addr_block_add_addrs(IPAddrBlocks *block, const struct ip_addr_block addrs[])
 static int
 build_addr_block_test(const struct build_addr_block_test_data *test)
 {
-	IPAddrBlocks	*addrs = NULL;
-	unsigned char	*out = NULL;
-	int		 out_len;
-	int		 i;
-	int		 memcmp_failed = 1;
-	int		 failed = 1;
+	IPAddrBlocks *addrs = NULL, *parsed = NULL;
+	const unsigned char *p;
+	unsigned char *out = NULL;
+	int out_len;
+	int i;
+	int memcmp_failed = 1;
+	int failed = 1;
 
 	if ((addrs = IPAddrBlocks_new()) == NULL)
 		goto err;
@@ -943,10 +944,34 @@ build_addr_block_test(const struct build_addr_block_test_data *test)
 		goto err;
 	}
 
+	p = test->der;
+	if ((parsed = d2i_IPAddrBlocks(NULL, &p, test->der_len)) == NULL) {
+		fprintf(stderr, "%s: \"%s\" d2i_IPAddrBlocks failed\n",
+		    __func__, test->description);
+		goto err;
+	}
+	if (!X509v3_addr_is_canonical(parsed)) {
+		fprintf(stderr, "%s: \"%s\" parsed AddrBlocks isn't canonical\n",
+		    __func__, test->description);
+		goto err;
+	}
+	/* Can't compare IPAddrBlocks with inheritance. */
+	if (!X509v3_addr_inherits(addrs) && !X509v3_addr_inherits(parsed)) {
+		if (!X509v3_addr_subset(addrs, parsed)) {
+			fprintf(stderr, "%s: \"%s\" addrs not subset of parsed\n",
+			    __func__, test->description);
+		}
+		if (!X509v3_addr_subset(parsed, addrs)) {
+			fprintf(stderr, "%s: \"%s\" parsed not subset of addrs\n",
+			    __func__, test->description);
+		}
+	}
+
 	failed = 0;
 
  err:
 	IPAddrBlocks_free(addrs);
+	IPAddrBlocks_free(parsed);
 	free(out);
 
 	return failed;
@@ -1495,10 +1520,6 @@ struct ASIdentifiers_subset_test {
 	int			 is_subset_if_canonized;
 };
 
-/*
- * XXX: X509v3_asid_subset() assumes that both asnum and rdi are present
- * while they are both marked OPTIONAL in RFC 3779, 3.2.3...
- */
 const struct ASIdentifiers_subset_test ASIdentifiers_subset_data[] = {
 	{
 		.description = "simple subset relation",
@@ -1539,6 +1560,147 @@ const struct ASIdentifiers_subset_test ASIdentifiers_subset_data[] = {
 		.is_subset = 1,
 		.is_subset_if_canonized = 1,
 	},
+	{
+		.description = "only asnums",
+		.delegationsA = {
+			{
+				.type = V3_ASID_ASNUM,
+				.inherit = 0,
+				.min = "2",
+				.max = "4",
+			},
+			{
+				.type = V3_ASID_END,
+			},
+		},
+		.delegationsB = {
+			{
+				.type = V3_ASID_ASNUM,
+				.inherit = 0,
+				.min = "1",
+				.max = "5",
+			},
+			{
+				.type = V3_ASID_END,
+			},
+		},
+		.is_subset = 1,
+		.is_subset_if_canonized = 1,
+	},
+	{
+		.description = "only rdis",
+		.delegationsA = {
+			{
+				.type = V3_ASID_RDI,
+				.inherit = 0,
+				.min = "2",
+				.max = NULL,
+			},
+			{
+				.type = V3_ASID_END,
+			},
+		},
+		.delegationsB = {
+			{
+				.type = V3_ASID_RDI,
+				.inherit = 0,
+				.min = "1",
+				.max = "5",
+			},
+			{
+				.type = V3_ASID_END,
+			},
+		},
+		.is_subset = 1,
+		.is_subset_if_canonized = 1,
+	},
+	{
+		.description = "child only has asnums, parent only has rdis",
+		.delegationsA = {
+			{
+				.type = V3_ASID_ASNUM,
+				.inherit = 0,
+				.min = "2",
+				.max = "4",
+			},
+			{
+				.type = V3_ASID_END,
+			},
+		},
+		.delegationsB = {
+			{
+				.type = V3_ASID_RDI,
+				.inherit = 0,
+				.min = "1",
+				.max = "5",
+			},
+			{
+				.type = V3_ASID_END,
+			},
+		},
+		.is_subset = 0,
+		.is_subset_if_canonized = 0,
+	},
+	{
+		.description = "child only has rdis, parent only has asnums",
+		.delegationsA = {
+			{
+				.type = V3_ASID_RDI,
+				.inherit = 0,
+				.min = "2",
+				.max = "4",
+			},
+			{
+				.type = V3_ASID_END,
+			},
+		},
+		.delegationsB = {
+			{
+				.type = V3_ASID_ASNUM,
+				.inherit = 0,
+				.min = "1",
+				.max = "5",
+			},
+			{
+				.type = V3_ASID_END,
+			},
+		},
+		.is_subset = 0,
+		.is_subset_if_canonized = 0,
+	},
+	{
+		.description = "child only has rdis, parent has both",
+		.delegationsA = {
+			{
+				.type = V3_ASID_RDI,
+				.inherit = 0,
+				.min = "2",
+				.max = "4",
+			},
+			{
+				.type = V3_ASID_END,
+			},
+		},
+		.delegationsB = {
+			{
+				.type = V3_ASID_ASNUM,
+				.inherit = 0,
+				.min = "1",
+				.max = "5",
+			},
+			{
+				.type = V3_ASID_RDI,
+				.inherit = 0,
+				.min = "1",
+				.max = "5",
+			},
+			{
+				.type = V3_ASID_END,
+			},
+		},
+		.is_subset = 1,
+		.is_subset_if_canonized = 1,
+	},
 	{
 		.description = "subset relation only after canonization",
 		.delegationsA = {
